@@ -3,7 +3,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 our @EXPORT = qw(all_vars_ok test_vars vars_ok);
 
@@ -339,6 +339,15 @@ sub _count_padvars {
         # refer to multiple pad variables.
         if($op->isa('B::UNOP_AUX')) {
             foreach my $i(grep {!ref}$ op->aux_list($cv)) {
+                # There is a bug in 5.24 with multideref aux_list where it can
+                # contain a value which is completely broken. It numifies to
+                # undef when used as an array index but "defined $i" will be
+                # true! We can detect it by comparing its stringified value to
+                # an empty string. This has been fixed in blead.
+                next unless do {
+                    no warnings;
+                    "$i" ne q{};
+                };
                 $pad[$i]{count}++
                     if $pad[$i];
             }
@@ -435,7 +444,7 @@ Test::Vars - Detects unused variables in perl modules
 
 =head1 VERSION
 
-This document describes Test::Vars version 0.012.
+This document describes Test::Vars version 0.013.
 
 =head1 SYNOPSIS
 
